AlekSIS (School Information System) — Core (Core functionality and app framework)
=================================================================================

AlekSIS standard distribution
-----------------------------

The AlekSIS standard distribution with information about all official apps
can be found on `EduGit`_.

Features
--------

The AlekSIS-Core currently provides the following features:

* For users:

 * Custom menu entries (e.g. in footer)
 * Global preferences
 * Group types
 * Manage announcements
 * Manage groups
 * Manage persons
 * Notifications via SMS email or dashboard
 * Rules and permissions for users, objects and pages
 * Two factor authentication via Yubikey, OTP or SMS
 * User preferences

* For admins

 * Asynchronous tasks with celery
 * Authentication via LDAP
 * Automatic backup of database, static and media files

Licence
-------

::

  Copyright © 2017, 2018, 2019, 2020 Jonathan Weth <wethjo@katharineum.de>
  Copyright © 2017, 2018, 2019 Frank Poetzsch-Heffter <p-h@katharineum.de>
  Copyright © 2018, 2019, 2020 Julian Leucker <leuckeju@katharineum.de>
  Copyright © 2018, 2019, 2020 Hangzhi Yu <yuha@katharineum.de>
  Copyright © 2019, 2020 Dominik George <dominik.george@teckids.org>
  Copyright © 2019, 2020 Tom Teichler <tom.teichler@teckids.org>
  Copyright © 2019 mirabilos <thorsten.glaser@teckids.org>

  Licenced under the EUPL, version 1.2 or later

Please see the LICENCE.rst file accompanying this distribution for the
full licence text or on the `European Union Public Licence`_ website
https://joinup.ec.europa.eu/collection/eupl/guidelines-users-and-developers
(including all other official language versions).

.. _AlekSIS: https://edugit.org/AlekSIS/Official/AlekSIS
.. _European Union Public Licence: https://eupl.eu/
.. _EduGit: https://edugit.org/AlekSIS/official/AlekSIS
